--------------------------------------------------------------------------
-- GTFO_Fail_MP.lua 
--------------------------------------------------------------------------
--[[
GTFO Fail List - Mists of Pandaria
Author: Zensunim of Malygos

Change Log:
	v4.13
		- Added Instructor Chillheart's Ice Wall
		- Added Instructor Chillheart's Frigid Grasp
		- Added Professor Slate's Fire Breath Potion
		- Added Ook-Ook's Brew Explosion
		- Added Ook-Ook's Ground Pound
		- Added Hopper's Explosive Brew
		- Added Yan-Zhu the Uncasked's Wall of Suds
		- Added Liu Flameheart's Serpent Wave
		- Added Wise Mari's Wash Away
		- Added Armsmaster Harlan's Dragon's Reach
		- Added Armsmaster Harlan's Blades of Light
		- Added Flameweaver Koegler's Greater Dragon's Breath
	v4.14
		- Rearranged spells, added placeholders
	v4.14.1
		- Added placeholders
		- Added Kuai the Brute's Shockwave
		- Added Ming the Cunning's Whirling Dervish
		- Added Xin the Weaponmaster's Ground Slam
		- Added Imperial Vizier Zor'lok's Sonic Pulse
		- Added Garalon's Crush
	v4.14.2
		- Added Big Bessa's Big Bessa's Cannon
		- Added Gatecrusher's Demolisher Shot
	v4.14.3
		- Added Master Snowdrift's Tornado Kick
		- Added Master Snowdrift's Ball of Fire (x2)

]]--

-- ***************
-- * Scholomance *
-- ***************

GTFO.SpellID["111231"] = {
	--desc = "Ice Wall (Instructor Chillheart)";
	sound = 3;
};

GTFO.SpellID["114886"] = {
	--desc = "Frigid Grasp (Instructor Chillheart)";
	sound = 3;
};

GTFO.SpellID["114038"] = {
	--desc = "Gravity Flux (Jandice Barov, Heroic)";
	sound = 3;
	test = true; -- Verify
};

GTFO.SpellID["114872"] = {
	--desc = "Fire Breath Potion (Professor Slate)";
	sound = 3;
	tankSound = 0;
};

-- **********************
-- * Stormstout Brewery *
-- **********************

GTFO.SpellID["106648"] = {
	--desc = "Brew Explosion (Ook-Ook)";
	sound = 3;
};

GTFO.SpellID["106808"] = {
	--desc = "Ground Pound (Ook-Ook)";
	soundFunction = function() 
		-- Only alert the first failed one per volley
		GTFO_AddEvent("GroundPound", 4);
		return 3;
	end;
	ignoreEvent = "GroundPound";	
};

GTFO.SpellID["114291"] = {
	--desc = "Explosive Brew (Hopper)";
	sound = 3;
	test = true; -- Might be spammy, don't know if these are avoidable or not
};

GTFO.SpellID["114466"] = {
	--desc = "Wall of Suds (Yan-Zhu the Uncasked)";
	sound = 3;
	test = true; -- Wild guess at spell ID
};

-- ******************************
-- * Temple of the Jade Serpent *
-- ******************************

GTFO.SpellID["106938"] = {
	--desc = "Serpent Wave (Liu Flameheart, TJS)";
	sound = 3;
};

GTFO.SpellID["106334"] = {
	--desc = "Wash Away (Wise Mari, TJS)";
	sound = 3;
	trivialPercent = 0;
};

-- *****************
-- * Scarlet Halls *
-- *****************

GTFO.SpellID["111217"] = {
	--desc = "Dragon's Reach (Armsmaster Harlan)";
	sound = 3;
	tankSound = 0;
	trivialPercent = 0;
};

GTFO.SpellID["112955"] = {
	--desc = "Blades of Light (Armsmaster Harlan)";
	sound = 3;
	applicationOnly = true;
};

GTFO.SpellID["113653"] = {
	--desc = "Greater Dragon's Breath (Flameweaver Koegler)";
	sound = 3;
	trivialPercent = 0;
	applicationOnly = true;
};

-- ***************************
-- * Gate of the Setting Sun *
-- ***************************

-- TODO: Sabotage (Saboteur Kip'tilak) (if avoidable) 
-- TODO: Mantid Munition Explosion (Saboteur Kip'tilak) (if avoidable)
-- TODO: Strafing Run (Striker Ga'dok) 
-- TODO: Bombard (Commander Ri'mok) (avoidable? non-tank only?)
-- TODO: Battering Headbutt (Raigonn)
-- TODO: Stomp (Raigonn) (is it avoidable? non-tank?)

-- ********************
-- * Mogu'shan Palace *
-- ********************

GTFO.SpellID["119922"] = {
	--desc = "Shockwave (Kuai the Brute)";
	sound = 3;
	test = true; -- Verify
};

GTFO.SpellID["121251"] = {
	--desc = "Whirling Dervish (Ming the Cunning)";
	sound = 3;
	test = true; -- Verify
};

GTFO.SpellID["119684"] = {
	--desc = "Ground Slam (Xin the Weaponmaster)";
	sound = 3;
};

-- TODO: Circle of Flame (Xin the Weaponmaster) (after explosion)

-- ***********************
-- * Shado-Pan Monastery *
-- ***********************

GTFO.SpellID["106433"] = {
	--desc = "Tornado Kick (Master Snowdrift)";
	sound = 3;
	test = true; -- Verify
};

GTFO.SpellID["106470"] = {
	--desc = "Ball of Fire - Blue (Master Snowdrift)";
	sound = 3;
	test = true; -- Verify
};

GTFO.SpellID["106413"] = {
	--desc = "Ball of Fire - Red (Master Snowdrift)";
	sound = 3;
	test = true; -- Verify
};

-- **************************
-- * Siege of Nivzao Temple *
-- **************************
-- TODO: Bombard (Sik'thik Amberwing) (avoidable?)
-- TODO: Unstable Blast (Sik'thik Demolisher) (avoidable?)
-- TODO: Blade Rush (General Pa'valak) (multiple spells? 1 for impact, 1 for rush)
-- TODO: Siege Explosive (General Pa'valak) (avoidable?)
-- TODO: Thrown Explosive (General Pa'valak) (avoidable? caused by players? does it do damage?)

-- *****************
-- * Heart of Fear *
-- *****************

GTFO.SpellID["124673"] = {
	--desc = "Sonic Pulse (Imperial Vizier Zor'lok)";
	sound = 3;
	trivialPercent = 0;
};

-- TODO: Tempest Slash (Blade Lord Ta'yak) (tornado could be high damage instead of fail)
-- TODO: Wind Step (Blade Lord Ta'yak) (fail if player wasn't the intended target)
-- TODO: Furious Swipe (Garalon) (non-tank fail)

GTFO.SpellID["123120"] = {
	--desc = "Crush (Garalon)";
	sound = 3;
	trivialPercent = 0;
	test = true; -- Verify
};


-- TODO: Whirling Blade (Wind Lord Mel'jarak)
-- TODO: Wind Bomb (Wind Lord Mel'jarak) (impact)
-- TODO: Wind Bomb (Wind Lord Mel'jarak) (detonation, caused by a player getting too close, need to determine who did it, probably raid wiper)
-- TODO: Amber Prison (Wind Lord Mel'jarak) (fail if player wasn't the intended target)
-- TODO: Living Amber (Amber-Shaper Un'sok) (explosion? avoidable?)
-- TODO: Massive Stomp (Amber Monstrosity) 
-- TODO: Fling (Amber Monstrosity) (FF to the target, don't alert the thrown player)
-- TODO: Volatile Amber (Amber-Shaper Un'sok) (avoidable)
-- TODO: Amber Globule (Amber-Shaper Un'sok) (only warn if the player was the intended target)
-- TODO: Sonic Discharge (Grand Empress Shek'zeer) (only fail if the player was in a dissonance field at the time, maybe)
-- TODO: Dread Screech (Grand Empress Shek'zeer) (fail if the players weren't the intended targets)
-- TODO: Amber Trap (Grand Empress Shek'zeer) (fail when afflicated)
-- TODO: Toxic Slime (Grand Empress Shek'zeer) (non-tank fail)
-- TODO: Consuming Terror (Grand Empress Shek'zeer) (non-tank fail)

-- ********************
-- * Mogu'shan Vaults *
-- ********************
-- TODO: Cobalt Mine (Stone Guard)
-- TODO: Lightning Fists (Feng the Accursed) (Non-tank fail)
-- TODO: Lightning Fists (Feng the Accursed, Heroic) (Non-tank fail)
-- TODO: Frail Soul (Gara'jal the Spiritbinder) (Death from crossing over with debuff)
-- TODO: Annihilate (The Spirit Kings) (Non-tank fail)
-- TODO: Shadow Blast (The Spirit Kings) (Not sure if this is avoidable)
-- TODO: Energy Cascade (Elegon) (If avoidable)
-- TODO: Energizing Smash (Will of the Emperor) (Non-tank fail)
-- TODO: Devastating Arc (Will of the Emperor) (If avoidable)
-- TODO: Stomp (Will of the Emperor) (Non-tank fail if boss isn't rooted?)

-- *****************************
-- * Terrace of Endless Spring *
-- *****************************
-- TODO: Lightning Storm (Elder Regail)
-- TODO: Water Bolt (Elder Asani) (See if it's possible to avoid)
-- TODO: Nightmares (Tsulong) (See if it's possible to avoid)
-- TODO: Shadow Breath (Tsulong) (Non-tank fail)
-- TODO: Spray (Lei Shi)
-- TODO: Breath of Fear (Sha of Fear)
-- TODO: Eerie Skull (Sha of Fear)
-- TODO: Penetrating Bolt (Sha of Fear)
-- TODO: Waterspout (Sha of Fear)
-- TODO: Submerge (Sha of Fear) (Avoidable?)

-- ****************
-- * World Bosses *
-- ****************

-- TODO: Cannon Barrage (Salyis's Warband)

-- ******************
-- * Theramore's Fall
-- ******************

GTFO.SpellID["114568"] = {
	--desc = "Big Bessa's Cannon (Big Bessa)";
	sound = 3;
	applicationOnly = true;
};

GTFO.SpellID["125915"] = {
	--desc = "Demolisher Shot (Gatecrusher)";
	sound = 3;
	applicationOnly = true;
};
